data "aws_region" "current" {}

data "aws_caller_identity" "current" {}

data "aws_iam_policy_document" "masters" {
  statement {
    actions = [
      "sts:AssumeRole",
    ]

    principals {
      type = "Service"

      identifiers = [
        "eks.amazonaws.com",
      ]
    }
  }
}

data "aws_ami" "eks_worker" {
  filter {
    name   = "name"
    values = ["eks-worker-*"]
  }

  most_recent = true
  owners      = ["602401143452"] # Amazon
}

data "aws_iam_policy_document" "workers" {
  statement {
    actions = [
      "sts:AssumeRole",
    ]

    principals {
      type = "Service"

      identifiers = [
        "ec2.amazonaws.com",
      ]
    }
  }
}

data "aws_iam_policy_document" "admin" {
  statement {
    actions = [
      "sts:AssumeRole",
    ]

    principals {
      type = "AWS"

      identifiers = [
        "arn:aws:iam::${data.aws_caller_identity.current.account_id}:root",
        "arn:aws:iam::${data.aws_caller_identity.current.account_id}:role/Steamhaus",
      ]
    }
  }
}

data "template_file" "kubeconfig" {
  template = "${file("${path.module}/templates/kubeconfig.tpl")}"

  vars {
    cluster_name        = "${var.cluster_name}"
    endpoint            = "${aws_eks_cluster.cluster.endpoint}"
    region              = "${data.aws_region.current.name}"
    cluster_auth_base64 = "${aws_eks_cluster.cluster.certificate_authority.0.data}"
  }
}

data "template_file" "config_map_aws_auth" {
  template = "${file("${path.module}/templates/config-map-aws-auth.yaml.tpl")}"

  vars {
    role_arn       = "${aws_iam_role.workers.arn}"
    admin_role_arn = "${aws_iam_role.admin.arn}"
  }
}

data "template_file" "workers_userdata" {
  template = "${file("${path.module}/templates/userdata.tpl")}"

  vars {
    region              = "${data.aws_region.current.name}"
    cluster_name        = "${var.cluster_name}"
    endpoint            = "${aws_eks_cluster.cluster.endpoint}"
    cluster_auth_base64 = "${aws_eks_cluster.cluster.certificate_authority.0.data}"
    max_pod_count       = "${var.max_pods_per_worker}"
    alt_dns_cluster_ip  = "${var.alt_dns_cluster_ip}"
    additional_userdata = "${var.additional_userdata}"
  }
}
